@@ -28,17 +28,17 @@
 
 #include "glpmat.h"
 
-#define chol_numb             _glp_chol_numb
-#define chol_symb             _glp_chol_symb
-#define create_adat           _glp_create_adat
-#define create_chol           _glp_create_chol
-#define decomp_adat           _glp_decomp_adat
-#define decomp_chol           _glp_decomp_chol
-#define delete_adat           _glp_delete_adat
-#define delete_chol           _glp_delete_chol
-#define min_deg               _glp_min_deg
-#define solve_adat            _glp_solve_adat
-#define solve_chol            _glp_solve_chol
+#define chol_numb             glp_chol_numb
+#define chol_symb             glp_chol_symb
+#define create_adat           glp_create_adat
+#define create_chol           glp_create_chol
+#define decomp_adat           glp_decomp_adat
+#define decomp_chol           glp_decomp_chol
+#define delete_adat           glp_delete_adat
+#define delete_chol           glp_delete_chol
+#define min_deg               glp_min_deg
+#define solve_adat            glp_solve_adat
+#define solve_chol            glp_solve_chol
 
 extern void chol_symb(MAT *A, MAT *U, int head[], int next[],
       char work[]);
