@@ -72,6 +72,9 @@
 #define ies_eval_red_cost     glp_ies_eval_red_cost
 #define ies_set_row_bnds      glp_ies_set_row_bnds
 #define ies_set_col_bnds      glp_ies_set_col_bnds
+#define ies_set_obj_c0        glp_ies_set_obj_c0
+#define ies_set_row_stat      glp_ies_set_row_stat
+#define ies_set_col_stat      glp_ies_set_col_stat
 #define ies_get_lp_object     glp_ies_get_lp_object
 #define ies_solve_node        glp_ies_solve_node
 
@@ -520,6 +523,15 @@ void ies_set_col_bnds(IESTREE *tree, IESITEM *col, int typx, double lb,
       double ub);
 /* set (change) column bounds */
 
+void ies_set_obj_c0(IESTREE *tree, double c0);
+/* set (change) constant term of the objective function */
+
+void ies_set_row_stat(IESTREE *tree, IESITEM *row, int stat);
+/* set (change) row status */
+
+void ies_set_col_stat(IESTREE *tree, IESITEM *col, int stat);
+/* set (change) column status */
+
 LPX *ies_get_lp_object(IESTREE *tree);
 /* get pointer to internal LP object */
 
