@@ -126,6 +126,7 @@
 #define lpx_eval_red_cost     glp_lpx_eval_red_cost
 #define lpx_reduce_form       glp_lpx_reduce_form
 #define lpx_mixed_gomory      glp_lpx_mixed_gomory
+#define lpx_estim_obj_chg     glp_lpx_estim_obj_chg
 
 #define lpx_read_mps          glp_lpx_read_mps
 #define lpx_write_mps         glp_lpx_write_mps
@@ -135,6 +136,8 @@
 
 #define lpx_read_lpm          glp_lpx_read_lpm
 
+#define lpx_read_lpt          glp_lpx_read_lpt
+
 /*----------------------------------------------------------------------
 -- The structure LPX defines LP/MIP problem object, which includes the
 -- following information:
@@ -607,7 +610,7 @@ struct LPX
 #define LPX_E_SING      211   /* problems with basis matrix */
 #define LPX_E_NOCONV    212   /* no convergence (interior) */
 
-/* control parameter identifiers */
+/* control parameter identifiers: */
 #define LPX_K_MSGLEV    300   /* lp->msg_lev */
 #define LPX_K_SCALE     301   /* lp->scale */
 #define LPX_K_DUAL      302   /* lp->dual */
@@ -928,6 +931,10 @@ int lpx_mixed_gomory(LPX *lp, int kind[], int len, int ndx[],
       double val[], double work[]);
 /* generate Gomory's mixed integer cut */
 
+void lpx_estim_obj_chg(LPX *lp, int k, double dn_val, double up_val,
+      double *dn_chg, double *up_chg, int ndx[], double val[]);
+/* estimate obj. changes for down- and up-branch */
+
 /* additional utility routines ---------------------------------------*/
 
 LPX *lpx_read_mps(char *fname);
@@ -948,6 +955,9 @@ int lpx_print_mip(LPX *lp, char *fname);
 LPX *lpx_read_lpm(char *infile, char *outfile);
 /* read LP/MIP model written in GLPK/L */
 
+LPX *lpx_read_lpt(char *fname);
+/* read LP/MIP problem using CPLEX LP format */
+
 #endif
 
 /* eof */
