@@ -50,7 +50,6 @@
 #define inv_per               glp_inv_per
 #define iper_vec              glp_iper_vec
 #define l_solve               glp_l_solve
-#define load_mat              glp_load_mat
 #define lt_solve              glp_lt_solve
 #define mat_per               glp_mat_per
 #define mat_vec               glp_mat_vec
@@ -61,9 +60,7 @@
 #define per_sym               glp_per_sym
 #define per_vec               glp_per_vec
 #define reset_per             glp_reset_per
-#define save_mat              glp_save_mat
 #define scrape_mat            glp_scrape_mat
-#define show_mat              glp_show_mat
 #define sort_mat              glp_sort_mat
 #define submatrix             glp_submatrix
 #define sum_mplets            glp_sum_mplets
@@ -200,9 +197,6 @@ extern double *iper_vec(double y[], PER *P, double x[]);
 extern double *l_solve(MAT *L, double x[]);
 /* solve lower triangular system L*x = b */
 
-extern MAT *load_mat(char *fname);
-/* read sparse matrix from text file using plain format */
-
 extern double *lt_solve(MAT *L, double x[]);
 /* solve transposed lower triangular system L'*x = b */
 
@@ -233,15 +227,9 @@ extern double *per_vec(double y[], PER *P, double x[]);
 extern PER *reset_per(PER *P);
 /* reset permutation matrix (P := I) */
 
-extern int save_mat(MAT *A, char *fname);
-/* write sparse matrix to text file using plain format */
-
 extern int scrape_mat(MAT *A, double eps);
 /* remove tiny elements from sparse matrix */
 
-extern int show_mat(MAT *A, int type, char *fname);
-/* output matrix pattern as raster image */
-
 extern MAT *sort_mat(MAT *A);
 /* ordering row and column lists of sparse matrix */
 
