@@ -42,7 +42,7 @@ typedef struct MPSQFE MPSQFE;
 
 struct MPS
 {     /* linear programming model in MPS format */
-      POOL *pool;
+      DMP *pool;
       /* memory pool holding all relevant data structures */
       char *name;
       /* model name */
