@@ -28,37 +28,37 @@
 
 #include "glplpx.h"
 
-#define spx_invert            _glp_spx_invert
-#define spx_ftran             _glp_spx_ftran
-#define spx_btran             _glp_spx_btran
-#define spx_update            _glp_spx_update
+#define spx_invert            glp_spx_invert
+#define spx_ftran             glp_spx_ftran
+#define spx_btran             glp_spx_btran
+#define spx_update            glp_spx_update
 
-#define spx_eval_xn_j         _glp_spx_eval_xn_j
-#define spx_eval_bbar         _glp_spx_eval_bbar
-#define spx_eval_pi           _glp_spx_eval_pi
-#define spx_eval_cbar         _glp_spx_eval_cbar
-#define spx_eval_obj          _glp_spx_eval_obj
-#define spx_eval_col          _glp_spx_eval_col
-#define spx_eval_rho          _glp_spx_eval_rho
-#define spx_eval_row          _glp_spx_eval_row
-#define spx_check_bbar        _glp_spx_check_bbar
-#define spx_check_cbar        _glp_spx_check_cbar
-#define spx_prim_chuzc        _glp_spx_prim_chuzc
-#define spx_prim_chuzr        _glp_spx_prim_chuzr
-#define spx_dual_chuzr        _glp_spx_dual_chuzr
-#define spx_dual_chuzc        _glp_spx_dual_chuzc
-#define spx_update_bbar       _glp_spx_update_bbar
-#define spx_update_pi         _glp_spx_update_pi
-#define spx_update_cbar       _glp_spx_update_cbar
-#define spx_change_basis      _glp_spx_change_basis
-#define spx_err_in_bbar       _glp_spx_err_in_bbar
-#define spx_err_in_pi         _glp_spx_err_in_pi
-#define spx_err_in_cbar       _glp_spx_err_in_cbar
-#define spx_reset_refsp       _glp_spx_reset_refsp
-#define spx_update_gvec       _glp_spx_update_gvec
-#define spx_err_in_gvec       _glp_spx_err_in_gvec
-#define spx_update_dvec       _glp_spx_update_dvec
-#define spx_err_in_dvec       _glp_spx_err_in_dvec
+#define spx_eval_xn_j         glp_spx_eval_xn_j
+#define spx_eval_bbar         glp_spx_eval_bbar
+#define spx_eval_pi           glp_spx_eval_pi
+#define spx_eval_cbar         glp_spx_eval_cbar
+#define spx_eval_obj          glp_spx_eval_obj
+#define spx_eval_col          glp_spx_eval_col
+#define spx_eval_rho          glp_spx_eval_rho
+#define spx_eval_row          glp_spx_eval_row
+#define spx_check_bbar        glp_spx_check_bbar
+#define spx_check_cbar        glp_spx_check_cbar
+#define spx_prim_chuzc        glp_spx_prim_chuzc
+#define spx_prim_chuzr        glp_spx_prim_chuzr
+#define spx_dual_chuzr        glp_spx_dual_chuzr
+#define spx_dual_chuzc        glp_spx_dual_chuzc
+#define spx_update_bbar       glp_spx_update_bbar
+#define spx_update_pi         glp_spx_update_pi
+#define spx_update_cbar       glp_spx_update_cbar
+#define spx_change_basis      glp_spx_change_basis
+#define spx_err_in_bbar       glp_spx_err_in_bbar
+#define spx_err_in_pi         glp_spx_err_in_pi
+#define spx_err_in_cbar       glp_spx_err_in_cbar
+#define spx_reset_refsp       glp_spx_reset_refsp
+#define spx_update_gvec       glp_spx_update_gvec
+#define spx_err_in_gvec       glp_spx_err_in_gvec
+#define spx_update_dvec       glp_spx_update_dvec
+#define spx_err_in_dvec       glp_spx_err_in_dvec
 
 typedef struct SPX SPX;
 
