@@ -34,7 +34,7 @@
 -- on the simplex method is used.
 ----------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.2";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.2.2";
 /* the version string */
 
 static char *in_fname = NULL;
@@ -43,6 +43,7 @@ static char *in_fname = NULL;
 static int format = 'M';
 /* format of the input text file:
    'M' - MPS
+   'T' - CPLEX LP format
    'L' - GLPK/L */
 
 static int check = 0;
@@ -118,10 +119,12 @@ static void display_help(char *my_name)
 {     print("Usage: %s [options...] filename", my_name);
       print("");
       print("General options:");
-      print("   --mps             read LP/MIP data using MPS format (de"
-         "fault)");
-      print("   --lpm             read LP/MIP model written in GLPK/L m"
-         "odeling");
+      print("   --mps             read LP/MIP problem using MPS format "
+         "(default)");
+      print("   --lpt             read LP/MIP problem using CPLEX LP fo"
+         "rmat");
+      print("   --lpm             read LP/MIP problem written in GLPK/L"
+         " modeling");
       print("                     language");
       print("   --check           do not solve the problem, check input"
          " data only");
@@ -160,8 +163,7 @@ static void display_help(char *my_name)
       print("Options specific to MIP:");
       print("   --nomip           consider all integer variables as con"
          "tinuous");
-      print("                     (this allows solving MIP problem as p"
-         "ure LP)");
+      print("                     (allows solving MIP as pure LP)");
       print("   --first           branch on first integer variable");
       print("   --last            branch on last integer variable");
       print("   --drtom           branch using heuristic by Driebeck an"
@@ -174,10 +176,17 @@ static void display_help(char *my_name)
          "euristic");
       print("                     (default)");
       print("");
+      print("For description of the MPS and CPLEX LP formats see Refere"
+         "nce Manual.");
+      print("For description of the modeling language see \"GLPK: Model"
+         "ing Language");
+      print("GLPK/L\".  Both documents are included in the GLPK distrib"
+         "ution.");
+      print("");
       print("See GLPK webpage at <http://www.gnu.org/software/glpk/glpk"
          ".html>");
       print("");
-      print("Report bugs to <bug-glpk@gnu.org>");
+      print("Please, report bugs to <bug-glpk@gnu.org>");
       exit(EXIT_SUCCESS);
       /* no return */
 }
@@ -212,6 +221,8 @@ static void process_cmdline(int argc, char *argv[])
       for (k = 1; k < argc; k++)
       {  if (p("--mps"))
             format = 'M';
+         else if (p("--lpt"))
+            format = 'T';
          else if (p("--lpm"))
             format = 'L';
          else if (p("--check"))
@@ -324,6 +335,13 @@ int main(int argc, char *argv[])
                exit(EXIT_FAILURE);
             }
             break;
+         case 'T':
+            lp = lpx_read_lpt(in_fname);
+            if (lp == NULL)
+            {  print("CPLEX LP file processing error");
+               exit(EXIT_FAILURE);
+            }
+            break;
          case 'L':
             lp = lpx_read_lpm(in_fname, fn_gener);
             if (lp == NULL)
