@@ -76,6 +76,7 @@ static void item_hook(void *info, IESITEM *item)
       {  case 'R':
             /* master row is being deleted */
             con = ies_get_item_link(bcs->tree, item);
+            insist(con->flag == BCS_CON_FLAG);
             /* inform the application procedure about that */
             bcs->event = BCS_V_DELCON;
             bcs->this_con = con;
@@ -83,11 +84,13 @@ static void item_hook(void *info, IESITEM *item)
             bcs->event = BCS_V_UNDEF;
             bcs->this_con = NULL;
             /* delete associated constraint from the workspace */
+            con->flag = 0;
             dmp_free_atom(bcs->con_pool, con);
             break;
          case 'C':
             /* master column is being deleted */
             var = ies_get_item_link(bcs->tree, item);
+            insist(var->flag == BCS_VAR_FLAG);
             /* inform the application procedure about that */
             bcs->event = BCS_V_DELVAR;
             bcs->this_var = var;
@@ -95,6 +98,7 @@ static void item_hook(void *info, IESITEM *item)
             bcs->event = BCS_V_UNDEF;
             bcs->this_var = NULL;
             /* delete associated variable from the workspace */
+            var->flag = 0;
             dmp_free_atom(bcs->var_pool, var);
             break;
          default:
@@ -111,8 +115,11 @@ static void item_hook(void *info, IESITEM *item)
 
 static void node_hook(void *info, IESNODE *node)
 {     BCS *bcs = info;
-      BCSJOB *job = ies_get_node_link(bcs->tree, node);
+      BCSJOB *job;
+      job = ies_get_node_link(bcs->tree, node);
+      insist(job->flag == BCS_JOB_FLAG);
       /* delete associated subproblem from the workspace */
+      job->flag = 0;
       dmp_free_atom(bcs->job_pool, job);
       return;
 }
@@ -142,6 +149,7 @@ static BCS *create_wksp(char *name, int dir,
       bcs->info = info;
       bcs->appl = appl;
       bcs->event = BCS_V_UNDEF;
+      bcs->br_var = NULL;
       bcs->this_var = NULL;
       bcs->this_con = NULL;
       bcs->found = 0;
@@ -176,6 +184,7 @@ static BCS *create_wksp(char *name, int dir,
 static BCSJOB *new_job(BCS *bcs, BCSJOB *parent)
 {     BCSJOB *job;
       job = dmp_get_atom(bcs->job_pool);
+      job->flag = BCS_JOB_FLAG;
       job->node = ies_create_node(bcs->tree, parent == NULL ? NULL :
          parent->node);
       job->node->link = job;
@@ -789,7 +798,6 @@ static void bcs_delete_wksp(BCS *bcs)
 int bcs_driver(char *name, int dir,
       void *info, void (*appl)(void *info, BCS *bcs))
 {     BCS *bcs;
-      BCSVAR *var;
       BCSJOB *job, *child;
       LPX *lp;
       int nonint;
@@ -898,25 +906,34 @@ loop: /* main loop starts here */
       }
       /* the solution is still integer infeasible; choose a branching
          variable */
-      var = choose_branch(bcs);
-      insist(var != NULL);
+      bcs->event = BCS_V_BRANCH;
+      bcs->br_var = NULL;
+      appl(bcs->info, bcs);
+      bcs->event = BCS_V_UNDEF;
+      /* if no branching variable has been chosen by the application
+         procedure, choose something appropriate */
+      if (bcs->br_var == NULL) bcs->br_var = choose_branch(bcs);
+      /* at this point the branching variable has to be chosen */
+      insist(bcs->br_var != NULL);
+      insist(bcs->br_var->attr & BCS_NONINT);
       /* clear the non-integer attributes */
       clear_nonint(bcs);
-      /* obtain value of the branching variable in the basic solution
-         of the current subproblem */
-      ies_get_col_info(bcs->tree, var->col, NULL, &vx, NULL);
-      /* create the first child subproblem and set new upper bound of
-         the branching variable */
+      /* obtain a value of the branching variable in the optimal basic
+         solution of the current subproblem */
+      ies_get_col_info(bcs->tree, bcs->br_var->col, NULL, &vx, NULL);
+      /* derive one subproblem for the down branch, where the branching
+         variable is rounded down (i.e. its upper bound is decreased) */
       child = new_job(bcs, job);
       ies_revive_node(bcs->tree, child->node);
-      new_bound(bcs, var, 'U', floor(vx));
-      /* create the second child subproblem and set new lower bound of
-         the branching variable */
+      new_bound(bcs, bcs->br_var, 'U', floor(vx));
+      /* derive other subproblem for the up branch, where the branching
+         variable is rounded up (i.e. its lower bound is increased) */
       child = new_job(bcs, job);
       ies_revive_node(bcs->tree, child->node);
-      new_bound(bcs, var, 'L', ceil(vx));
-      /* the second child subproblem becomes the current one */
+      new_bound(bcs, bcs->br_var, 'L', ceil(vx));
+      /* the latter child subproblem becomes the current one */
       job = child;
+      /* continue the search */
       goto loop;
 fath: /* the current subproblem has been fathomed; prune the branch */
       ies_prune_branch(bcs->tree, job->node);
