@@ -170,9 +170,15 @@ BCSVAR *bcs_add_var(BCS *bcs, char *name, int attr, int typx,
       }
       /* replace temporarily pointers to constraints by pointers to the
          corresponding master rows */
-      for (t = 1; t <= len; t++) row[t] = con[t]->row;
+      for (t = 1; t <= len; t++)
+      {  if (!(con[t] != NULL && con[t]->flag == BCS_CON_FLAG))
+            fault("bcs_add_var: con[%d] = %p; invalid pointer",
+               t, con[t]);
+         row[t] = con[t]->row;
+      }
       /* create new variable */
       var = dmp_get_atom(bcs->var_pool);
+      var->flag = BCS_VAR_FLAG;
       var->col = ies_add_master_col(bcs->tree, name, typx, lb, ub, coef,
          len, row, val);
       ies_set_item_link(bcs->tree, var->col, var);
@@ -266,9 +272,15 @@ BCSCON *bcs_add_con(BCS *bcs, char *name, int attr, int typx,
          fault("bcs_add_con: attr = 0x%X; invalid attributes", attr);
       /* replace temporarily pointers to variables by pointers to the
          corresponding master columns */
-      for (t = 1; t <= len; t++) col[t] = var[t]->col;
+      for (t = 1; t <= len; t++)
+      {  if (!(var[t] != NULL && var[t]->flag == BCS_VAR_FLAG))
+            fault("bcs_add_con: var[%d] = %p; invalid pointer",
+               t, var[t]);
+         col[t] = var[t]->col;
+      }
       /* create new constraint */
       con = dmp_get_atom(bcs->con_pool);
+      con->flag = BCS_CON_FLAG;
       con->row = ies_add_master_row(bcs->tree, name, typx, lb, ub, 0.0,
          len, col, val);
       ies_set_item_link(bcs->tree, con->row, con);
@@ -302,6 +314,8 @@ BCSCON *bcs_add_con(BCS *bcs, char *name, int attr, int typx,
 
 BCSVAR *bcs_get_next_var(BCS *bcs, BCSVAR *var)
 {     IESITEM *col;
+      if (!(var == NULL || var->flag == BCS_VAR_FLAG))
+         fault("bcs_get_next_var: var = %p; invalid pointer", var);
       col = (var == NULL ? NULL : var->col);
       col = ies_next_master_col(bcs->tree, col);
       return (BCSVAR *)(col == NULL ? NULL : col->link);
@@ -327,6 +341,8 @@ BCSVAR *bcs_get_next_var(BCS *bcs, BCSVAR *var)
 
 BCSCON *bcs_get_next_con(BCS *bcs, BCSCON *con)
 {     IESITEM *row;
+      if (!(con == NULL || con->flag == BCS_CON_FLAG))
+         fault("bcs_get_next_con: con = %p; invalid pointer", con);
       row = (con == NULL ? NULL : con->row);
       row = ies_next_master_row(bcs->tree, row);
       return (BCSCON *)(row == NULL ? NULL : row->link);
@@ -353,6 +369,8 @@ BCSCON *bcs_get_next_con(BCS *bcs, BCSCON *con)
 
 void bcs_set_var_appl(BCS *bcs, BCSVAR *var, int disc, void *link)
 {     insist(bcs == bcs);
+      if (!(var != NULL && var->flag == BCS_VAR_FLAG))
+         fault("bcs_set_var_appl: var = %p; invalid pointer", var);
       var->disc = disc;
       var->link = link;
       return;
@@ -379,6 +397,8 @@ void bcs_set_var_appl(BCS *bcs, BCSVAR *var, int disc, void *link)
 
 void bcs_set_con_appl(BCS *bcs, BCSCON *con, int disc, void *link)
 {     insist(bcs == bcs);
+      if (!(con != NULL && con->flag == BCS_CON_FLAG))
+         fault("bcs_set_con_appl: con = %p; invalid pointer", con);
       con->disc = disc;
       con->link = link;
       return;
@@ -405,6 +425,8 @@ void bcs_set_con_appl(BCS *bcs, BCSCON *con, int disc, void *link)
 
 void bcs_get_var_appl(BCS *bcs, BCSVAR *var, int *disc, void **link)
 {     insist(bcs == bcs);
+      if (!(var != NULL && var->flag == BCS_VAR_FLAG))
+         fault("bcs_get_var_appl: var = %p; invalid pointer", var);
       if (disc != NULL) *disc = var->disc;
       if (link != NULL) *link = var->link;
       return;
@@ -431,6 +453,8 @@ void bcs_get_var_appl(BCS *bcs, BCSVAR *var, int *disc, void **link)
 
 void bcs_get_con_appl(BCS *bcs, BCSCON *con, int *disc, void **link)
 {     insist(bcs == bcs);
+      if (!(con != NULL && con->flag == BCS_CON_FLAG))
+         fault("bcs_get_con_appl: con = %p; invalid pointer", con);
       if (disc != NULL) *disc = con->disc;
       if (link != NULL) *link = con->link;
       return;
@@ -579,6 +603,9 @@ void bcs_get_var_info(BCS *bcs, BCSVAR *var, int *tagx, double *vx,
 {     /* the current subproblem should exist */
       if (ies_get_this_node(bcs->tree) == NULL)
          fault("bcs_get_var_info: current subproblem not exist");
+      /* check pointer to variable */
+      if (!(var != NULL && var->flag == BCS_VAR_FLAG))
+         fault("bcs_get_var_info: var = %p; invalid pointer", var);
       /* the specified variable should be presented in the current
          subproblem */
       if (ies_get_col_bind(bcs->tree, var->col) == 0)
@@ -622,6 +649,9 @@ void bcs_get_con_info(BCS *bcs, BCSCON *con, int *tagx, double *vx,
 {     /* the current subproblem should exist */
       if (ies_get_this_node(bcs->tree) == NULL)
          fault("bcs_get_con_info: current subproblem not exist");
+      /* check pointer to constraint */
+      if (!(con != NULL && con->flag == BCS_CON_FLAG))
+         fault("bcs_get_con_info: con = %p; invalid pointer", con);
       /* the specified constraint should be presented in the current
          subproblem */
       if (ies_get_row_bind(bcs->tree, con->row) == 0)
