@@ -338,15 +338,15 @@ fail: {  print("load_hbsm: format `%s' not recognised", fmt);
       k = 1;
       /* optional scale factor */
       fmt_p = 0;
-      if (isdigit(fmt[k]))
+      if (isdigit((unsigned char)fmt[k]))
       {  s = 0;
-         while (isdigit(fmt[k]))
+         while (isdigit((unsigned char)fmt[k]))
          {  if (s == 80) goto fail;
             str[s++] = fmt[k++];
          }
          str[s] = '\0';
          if (str2int(str, &val)) goto fail;
-         if (toupper(fmt[k]) != 'P') goto iter;
+         if (toupper((unsigned char)fmt[k]) != 'P') goto iter;
          fmt_p = val, k++;
          if (!(0 <= fmt_p && fmt_p <= 255)) goto fail;
          /* optional comma may follow scale factor */
@@ -354,9 +354,9 @@ fail: {  print("load_hbsm: format `%s' not recognised", fmt);
       }
       /* optional iterator */
       fmt_k = 1;
-      if (isdigit(fmt[k]))
+      if (isdigit((unsigned char)fmt[k]))
       {  s = 0;
-         while (isdigit(fmt[k]))
+         while (isdigit((unsigned char)fmt[k]))
          {  if (s == 80) goto fail;
             str[s++] = fmt[k++];
          }
@@ -366,13 +366,13 @@ iter:    fmt_k = val;
          if (!(1 <= fmt_k && fmt_k <= 255)) goto fail;
       }
       /* format code */
-      fmt_f = toupper(fmt[k++]);
+      fmt_f = toupper((unsigned char)fmt[k++]);
       if (!(fmt_f == 'D' || fmt_f == 'E' || fmt_f == 'F' ||
             fmt_f == 'G' || fmt_f == 'I')) goto fail;
       /* field width */
-      if (!isdigit(fmt[k])) goto fail;
+      if (!isdigit((unsigned char)fmt[k])) goto fail;
       s = 0;
-      while (isdigit(fmt[k]))
+      while (isdigit((unsigned char)fmt[k]))
       {  if (s == 80) goto fail;
          str[s++] = fmt[k++];
       }
@@ -383,9 +383,9 @@ iter:    fmt_k = val;
       fmt_d = 0;
       if (fmt[k] == '.')
       {  k++;
-         if (!isdigit(fmt[k])) goto fail;
+         if (!isdigit((unsigned char)fmt[k])) goto fail;
          s = 0;
-         while (isdigit(fmt[k]))
+         while (isdigit((unsigned char)fmt[k]))
          {  if (s == 80) goto fail;
             str[s++] = fmt[k++];
          }
@@ -463,7 +463,8 @@ static int read_real_array(char *name, char *fmt, int n, double val[])
             return 1;
          }
          /* sometimes lower case letters appear */
-         for (ptr = str; *ptr; ptr++) *ptr = (char)toupper(*ptr);
+         for (ptr = str; *ptr; ptr++)
+            *ptr = (char)toupper((unsigned char)*ptr);
          ptr = strchr(str, 'D');
          if (ptr != NULL) *ptr = 'E';
          /* value may appear with decimal exponent but without letters
