@@ -785,8 +785,9 @@ void ies_set_item_hook(IESTREE *tree,
 --
 -- *Description*
 --
--- The routine deletes the implicit enumeration tree specified by the
--- parameter tree and frees all the memory allocated to this object. */
+-- The routine ies_delete_tree deletes the implicit enumeration tree,
+-- which the parameter tree points to, and frees all memory allocated
+-- to this object. */
 
 void ies_delete_tree(IESTREE *tree)
 {     dmp_delete_pool(tree->item_pool);
