@@ -815,15 +815,160 @@ void ies_set_col_bnds(IESTREE *tree, IESITEM *col, int typx, double lb,
       return;
 }
 
-void ies_set_obj_c0(IESTREE *tree, double c0);
+/*----------------------------------------------------------------------
+-- ies_set_obj_c0 - set (change) constant term of the obj. function.
+--
+-- *Synopsis*
+--
+-- #include "glpies.h"
+-- void ies_set_obj_c0(IESTREE *tree, double c0);
+--
+-- *Description*
+--
+-- The routine ies_set_obj_c0 sets (changes) the constant term of the
+-- objective function for the current node problem, which should exist
+-- and be active. */
+
+void ies_set_obj_c0(IESTREE *tree, double c0)
+{     IESNODE *node;
+      /* get a pointer to the current node problem */
+      node = tree->this_node;
+      /* the current node problem should exist */
+      if (node == NULL)
+         fault("ies_set_obj_c0: current node problem not exist");
+      /* and should be active */
+      if (node->count >= 0)
+         fault("ies_set_obj_c0: attempt to modify inactive node problem"
+            );
+      /* set new constant term of the objective function */
+      tree->coef[0] = c0;
+      lpx_set_obj_c0(tree->lp, c0);
+      return;
+}
 
 void ies_set_row_coef(IESTREE *tree, IESITEM *row, double coef);
 
 void ies_set_col_coef(IESTREE *tree, IESITEM *col, double coef);
 
-void ies_set_row_stat(IESTREE *tree, IESITEM *row, int stat);
+/*----------------------------------------------------------------------
+-- ies_set_row_stat - set (change) row status.
+--
+-- *Synopsis*
+--
+-- #include "glpies.h"
+-- void ies_set_row_stat(IESTREE *tree, IESITEM *row, int stat);
+--
+-- *Description*
+--
+-- The routine ies_set_row_stat sets (changes) status of the specified
+-- row in the current node problem.
+--
+-- The current node problem should exist and be active. The specified
+-- row should be presented in the current node problem.
+--
+-- New status of the row (of the corresponding auxiliary variable) is
+-- determined by the parameter stat as follows:
+--
+-- LPX_BS   - make the row basic (make the constraint inactive);
+-- LPX_NL   - make the row non-basic (make the constraint active);
+-- LPX_NU   - make the row non-basic and set it to the upper bound; if
+--            the row is not double-bounded, this status is equivalent
+--            to LPX_NL (only in the case of this routine);
+-- LPX_NF   - the same as LPX_NL (only in the case of this routine);
+-- LPX_NS   - the same as LPX_NL (only in the case of this routine). */
 
-void ies_set_col_stat(IESTREE *tree, IESITEM *col, int stat);
+void ies_set_row_stat(IESTREE *tree, IESITEM *row, int stat)
+{     IESNODE *node;
+      int i;
+      /* get a pointer to the current node problem */
+      node = tree->this_node;
+      /* the current node problem should exist */
+      if (node == NULL)
+         fault("ies_set_row_stat: current node problem not exist");
+      /* and should be active */
+      if (node->count >= 0)
+         fault("ies_set_row_stat: attempt to modify inactive node probl"
+            "em");
+      /* check if the pointer refers to an existing master row */
+      if (!(row->what == 'R' && row->count >= 0))
+         fault("ies_set_row_stat: row = %p; invalid master row pointer",
+            row);
+      /* the specified master row should be presented in the current
+         node problem */
+      if (row->bind == 0)
+         fault("ies_set_row_stat: row = %p; master row missing in curre"
+            "nt node problem");
+      /* set row status */
+      i = row->bind;
+      insist(tree->item[i] == row);
+      if (!(stat == LPX_BS || stat == LPX_NL || stat == LPX_NU ||
+            stat == LPX_NF || stat == LPX_NS))
+         fault("ies_set_row_stat: stat = %d; invalid status", stat);
+      lpx_set_row_stat(tree->lp, i, stat);
+      lpx_get_row_info(tree->lp, i, &stat, NULL, NULL);
+      tree->tagx[i] = stat;
+      return;
+}
+
+/*----------------------------------------------------------------------
+-- ies_set_col_stat - set (change) column status.
+--
+-- *Synopsis*
+--
+-- #include "glpies.h"
+-- void ies_set_col_stat(IESTREE *tree, IESITEM *col, int stat);
+--
+-- *Description*
+--
+-- The routine ies_set_col_stat sets (changes) status of the specified
+-- column in the current node problem.
+--
+-- The current node problem should exist and be active. The specified
+-- column should be presented in the current node problem.
+--
+-- New status of the column (of the corresponding structural variable)
+-- is determined by the parameter stat as follows:
+--
+-- LPX_BS   - make the column basic;
+-- LPX_NL   - make the column non-basic;
+-- LPX_NU   - make the column non-basic and set it to the upper bound;
+--            if the column is not of double-bounded type, this status
+--            is the same as LPX_NL (only in the case of this routine);
+-- LPX_NF   - the same as LPX_NL (only in the case of this routine);
+-- LPX_NS   - the same as LPX_NL (only in the case of this routine). */
+
+void ies_set_col_stat(IESTREE *tree, IESITEM *col, int stat)
+{     IESNODE *node;
+      int j;
+      /* get a pointer to the current node problem */
+      node = tree->this_node;
+      /* the current node problem should exist */
+      if (node == NULL)
+         fault("ies_set_col_stat: current node problem not exist");
+      /* and should be active */
+      if (node->count >= 0)
+         fault("ies_set_col_stat: attempt to modify inactive node probl"
+            "em");
+      /* check if the pointer refers to an existing master column */
+      if (!(col->what == 'C' && col->count >= 0))
+         fault("ies_set_col_stat: col = %p; invalid master column point"
+            "er", col);
+      /* the specified master column should be presented in the current
+         node problem */
+      if (col->bind == 0)
+         fault("ies_set_col_stat: col = %p; master column missing in cu"
+            "rrent node problem");
+      /* set column status */
+      j = tree->m + col->bind;
+      insist(tree->item[j] == col);
+      if (!(stat == LPX_BS || stat == LPX_NL || stat == LPX_NU ||
+            stat == LPX_NF || stat == LPX_NS))
+         fault("ies_set_col_stat: stat = %d; invalid status", stat);
+      lpx_set_col_stat(tree->lp, j - tree->m, stat);
+      lpx_get_col_info(tree->lp, j - tree->m, &stat, NULL, NULL);
+      tree->tagx[j] = stat;
+      return;
+}
 
 /*----------------------------------------------------------------------
 -- ies_get_lp_object - get pointer to internal LP object.
