@@ -25,7 +25,7 @@
 
 #include <ctype.h>
 #include <string.h>
-#include "glplang.h"
+#include "glplan.h"
 #include "glplib.h"
 
 /*----------------------------------------------------------------------
@@ -248,7 +248,7 @@ loop: if (token != T_NAME)
                strcpy(name, image);
                get_token(/* mute letter */);
             }
-            if (!(strlen(name) == 1 && islower(name[0])))
+            if (!(strlen(name) == 1 && islower((unsigned char)name[0])))
                fatal("invalid mute letter `%s'", name);
             mute = name[0];
             if (find_mute(spar->dim, spar->mute, mute) >= 0)
@@ -307,6 +307,11 @@ skip2:      node = avl_find_by_key(pdb->tree, name);
             if (t < 0)
                cond = expand_spar(cond, spar->set[k], spar->mute[k]);
          }
+#if 1
+         /* coordinate mute letters in the predicate with mute letters
+            in the variable array */
+         transpose(cond, spar->mute);
+#endif
       }
       else
       {  /* condition is not specified; by default it is 0ary predicate
