@@ -27,7 +27,7 @@
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
-#include "glplang.h"
+#include "glplan.h"
 #include "glplib.h"
 
 /*----------------------------------------------------------------------
