@@ -26,7 +26,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
-#include "glplang.h"
+#include "glplan.h"
 #include "glplib.h"
 #include "glpmat.h"
 
