@@ -25,7 +25,7 @@
 
 #include <ctype.h>
 #include <string.h>
-#include "glplang.h"
+#include "glplan.h"
 #include "glplib.h"
 
 /*----------------------------------------------------------------------
@@ -164,7 +164,8 @@ SPAR *designator(char *name)
             fatal("too many subscripts for `%s'", orig->name);
          if (token == T_NAME)
          {  /* parse mute letter */
-            if (!(strlen(image) == 1 && islower(image[0])))
+            if (!(strlen(image) == 1 &&
+               islower((unsigned char)image[0])))
                fatal("invalid mute letter `%s'", image);
             /* identical mute letters should refer to identical sets */
             t = find_mute(k, mute, image[0]);
@@ -323,8 +324,10 @@ skip: /* create resultant array */
             }
             /* identical mute letters should correspond to identical
                index set elements */
-            t = find_mute(k, mute, mute[k]);
-            if (t >= 0 && item[t] != item[k]) goto miss;
+            if (form[k] == 0 || form[k] == 1)
+            {  t = find_mute(k, mute, mute[k]);
+               if (t >= 0 && item[t] != item[k]) goto miss;
+            }
          }
          /* create resultant element and build its tuple */
          temp = dmp_get_atom(pdb->memb_pool);
@@ -420,6 +423,7 @@ SPAR *data_func(void)
       MEMB *memb;
       ITEM *item[MAX_DIM];
       AVLNODE *node;
+      NDX *ndx;
       int k;
       insist(t_spec("("));
       get_token(/* ( */);
@@ -429,14 +433,14 @@ SPAR *data_func(void)
       spar->type = 'X';
       spar->dim = 0;
       spar->first = spar->last = NULL;
-      create_index(spar);
+      ndx = create_index(spar);
       /* parse domain list */
       for (;;)
       {  if (spar->dim == MAX_DIM)
             fatal("array dimension too high");
          if (token != T_NAME)
             fatal("mute letter missing or invalid");
-         if (!(strlen(image) == 1 && islower(image[0])))
+         if (!(strlen(image) == 1 && islower((unsigned char)image[0])))
             fatal("invalid mute letter `%s'", image);
          if (find_mute(spar->dim, spar->mute, image[0]) >= 0)
             fatal("duplicate mute letter `%s'", image);
@@ -488,7 +492,7 @@ SPAR *data_func(void)
             if (t_spec(",")) get_token(/* , */);
          }
          /* check for duplicate tuple */
-         if (find_memb(item) != NULL)
+         if (find_memb(ndx, item) != NULL)
             fatal("duplicate tuple detected");
          /* parse expression */
          temp = expression();
@@ -506,14 +510,14 @@ SPAR *data_func(void)
             else
                spar->last->next = memb;
             spar->last = memb;
-            index_memb(memb);
+            index_memb(ndx, memb);
          }
          dmp_free_atom(pdb->spar_pool, temp);
          /* check delimiter */
          if (t_spec(")")) break;
          if (t_spec(",")) get_token(/* , */);
       }
-skip: delete_index();
+skip: delete_index(ndx);
       get_token(/* ) */);
       return spar;
 }
@@ -543,7 +547,8 @@ SPAR *sum_func(void)
                fatal("too many mute letters");
             if (token != T_NAME)
                fatal("mute letter missing or invalid");
-            if (!(strlen(image) == 1 && islower(image[0])))
+            if (!(strlen(image) == 1 &&
+               islower((unsigned char)image[0])))
                fatal("invalid mute letter `%s'", image);
             if (find_mute(n, mute, image[0]) >= 0)
                fatal("duplicate mute letter `%s'", image);
@@ -559,7 +564,7 @@ SPAR *sum_func(void)
       {  /* the only mute letter */
          if (token != T_NAME)
             fatal("mute letter missing or invalid");
-         if (!(strlen(image) == 1 && islower(image[0])))
+         if (!(strlen(image) == 1 && islower((unsigned char)image[0])))
             fatal("invalid mute letter `%s'", image);
          n = 1;
          mute[0] = image[0];
@@ -598,6 +603,7 @@ SPAR *table_func(void)
       AVLNODE *node;
       MEMB *memb;
       ITEM *col[1+MAX_COLS], *row, *item[2];
+      NDX *ndx;
       int n, k;
       insist(t_spec("("));
       get_token(/* ( */);
@@ -611,7 +617,7 @@ SPAR *table_func(void)
       for (k = 0; k <= 1; k++)
       {  if (token != T_NAME)
             fatal("mute letter missing or invalid");
-         if (!(strlen(image) == 1 && islower(image[0])))
+         if (!(strlen(image) == 1 && islower((unsigned char)image[0])))
             fatal("invalid mute letter `%s'", image);
          if (find_mute(k, spar->mute, image[0]) >= 0)
             fatal("duplicate mute letter `%s'", image);
@@ -659,7 +665,7 @@ SPAR *table_func(void)
       }
       get_token(/* : */);
       /* parse row list */
-      create_index(spar);
+      ndx = create_index(spar);
       for (;;)
       {  if (token != T_NAME)
             fatal("row name missing or invalid");
@@ -681,7 +687,7 @@ SPAR *table_func(void)
             else
             {  /* check for duplicate tuple */
                item[0] = row, item[1] = col[k];
-               if (find_memb(item) != NULL)
+               if (find_memb(ndx, item) != NULL)
                   fatal("duplicate tuple detected");
                /* parse expression */
                temp = expression();
@@ -700,7 +706,7 @@ SPAR *table_func(void)
                   else
                      spar->last->next = memb;
                   spar->last = memb;
-                  index_memb(memb);
+                  index_memb(ndx, memb);
                }
                dmp_free_atom(pdb->spar_pool, temp);
             }
@@ -710,7 +716,7 @@ SPAR *table_func(void)
          if (t_spec(")")) break;
          if (t_spec(",")) get_token(/* , */);
       }
-      delete_index();
+      delete_index(ndx);
       get_token(/* ) */);
       return spar;
 }
