@@ -24,7 +24,7 @@
 ----------------------------------------------------------------------*/
 
 #include <string.h>
-#include "glplang.h"
+#include "glplan.h"
 #include "glplib.h"
 
 /*----------------------------------------------------------------------
@@ -159,6 +159,7 @@ SPAR *unary_op(int op, SPAR *x)
 SPAR *addition(int op, SPAR *x, SPAR *y)
 {     SPAR *set[MAX_DIM];
       MEMB *memb, *temp;
+      NDX *ndx;
       int dim, mute[MAX_DIM], k, t;
       if (!(x->type == 'X' && y->type == 'X'))
          fatal("invalid operand of binary arithmetic operation");
@@ -209,14 +210,14 @@ SPAR *addition(int op, SPAR *x, SPAR *y)
             insist(op != op);
       }
       /* index elements of the first operand */
-      create_index(x);
+      ndx = create_index(x);
       for (memb = x->first; memb != NULL; memb = memb->next)
-         index_memb(memb);
+         index_memb(ndx, memb);
       /* x := x op y */
       while (y->first != NULL)
       {  memb = y->first;
          y->first = memb->next;
-         temp = find_memb(memb->item);
+         temp = find_memb(ndx, memb->item);
          if (temp == NULL)
          {  /* member not found */
             if (op == C_SUB)
@@ -227,7 +228,7 @@ SPAR *addition(int op, SPAR *x, SPAR *y)
             else
                x->last->next = memb;
             x->last = memb;
-            index_memb(memb);
+            index_memb(ndx, memb);
          }
          else
          {  /* member already exists */
@@ -236,7 +237,7 @@ SPAR *addition(int op, SPAR *x, SPAR *y)
          }
       }
       dmp_free_atom(pdb->spar_pool, y);
-      delete_index();
+      delete_index(ndx);
       return x;
 }
 
@@ -341,6 +342,7 @@ miss:       ;
 SPAR *selection(SPAR *x, SPAR *y)
 {     MEMB *memb, *list;
       ITEM *item[MAX_DIM];
+      NDX *ndx;
       int k, t;
       if (!(x->type == 'X' && y->type == 'P'))
          fatal("invalid operand of selection operation");
@@ -355,9 +357,9 @@ SPAR *selection(SPAR *x, SPAR *y)
                y->mute[k]);
       }
       /* index predicate members */
-      create_index(y);
+      ndx = create_index(y);
       for (memb = y->first; memb != NULL; memb = memb->next)
-         index_memb(memb);
+         index_memb(ndx, memb);
       /* select members of the first operand and build the resultant
          array */
       list = x->first;
@@ -368,7 +370,7 @@ SPAR *selection(SPAR *x, SPAR *y)
          {  t = find_mute(x->dim, x->mute, y->mute[k]);
             item[k] = memb->item[t];
          }
-         if (find_memb(item) == NULL)
+         if (find_memb(ndx, item) == NULL)
          {  erase_expr(memb->link);
             dmp_free_atom(pdb->memb_pool, memb);
          }
@@ -381,7 +383,7 @@ SPAR *selection(SPAR *x, SPAR *y)
             x->last = memb;
          }
       }
-      delete_index();
+      delete_index(ndx);
       erase_spar(y);
       return x;
 }
@@ -475,6 +477,7 @@ SPAR *logical_not(SPAR *x)
 {     SPAR *z;
       ITEM *item[MAX_DIM];
       MEMB *ptr[MAX_DIM], *memb;
+      NDX *ndx;
       int k, t;
       if (x->type != 'P')
          fatal("invalid operand of unary logical operation");
@@ -490,9 +493,9 @@ SPAR *logical_not(SPAR *x)
          if (ptr[k] == NULL) goto skip;
       }
       /* index elements of the input predicate */
-      create_index(x);
+      ndx = create_index(x);
       for (memb = x->first; memb != NULL; memb = memb->next)
-         index_memb(memb);
+         index_memb(ndx, memb);
       /* generate all tuples of the cartesian product */
       for (;;)
       {  /* build the current tuple */
@@ -506,7 +509,7 @@ SPAR *logical_not(SPAR *x)
          }
          /* if the corresponding element is not in the predicate x,
             include it in the resultant predicate */
-         if (find_memb(item) == NULL)
+         if (find_memb(ndx, item) == NULL)
          {  memb = dmp_get_atom(pdb->memb_pool);
             for (t = 0; t < x->dim; t++)
                memb->item[t] = item[t];
@@ -521,7 +524,7 @@ SPAR *logical_not(SPAR *x)
          /* check if the next tuple exists */
          if (k < 0) break;
       }
-      delete_index();
+      delete_index(ndx);
 skip: erase_spar(x);
       return z;
 }
@@ -617,6 +620,7 @@ miss:       ;
 SPAR *logical_or(SPAR *x, SPAR *y)
 {     SPAR *set[MAX_DIM];
       MEMB *memb, *temp;
+      NDX *ndx;
       int dim, mute[MAX_DIM], k, t;
       if (!(x->type == 'P' && y->type == 'P'))
          fatal("invalid operand of binary logical operation");
@@ -658,14 +662,14 @@ SPAR *logical_or(SPAR *x, SPAR *y)
       /* now both operands have the same dimension and mute letters */
       strcpy(x->name, "<logical or>");
       /* index elements of the first operand */
-      create_index(x);
+      ndx = create_index(x);
       for (memb = x->first; memb != NULL; memb = memb->next)
-         index_memb(memb);
+         index_memb(ndx, memb);
       /* x := x or y */
       while (y->first != NULL)
       {  memb = y->first;
          y->first = memb->next;
-         temp = find_memb(memb->item);
+         temp = find_memb(ndx, memb->item);
          if (temp == NULL)
          {  /* member not found */
             memb->link = NULL;
@@ -675,7 +679,7 @@ SPAR *logical_or(SPAR *x, SPAR *y)
             else
                x->last->next = memb;
             x->last = memb;
-            index_memb(memb);
+            index_memb(ndx, memb);
          }
          else
          {  /* member already exists */
@@ -683,7 +687,7 @@ SPAR *logical_or(SPAR *x, SPAR *y)
          }
       }
       dmp_free_atom(pdb->spar_pool, y);
-      delete_index();
+      delete_index(ndx);
       return x;
 }
 
@@ -699,6 +703,7 @@ SPAR *summation(SPAR *x, int n, int mute[MAX_DIM])
 {     SPAR *z;
       ITEM *item[MAX_DIM];
       MEMB *memb, *temp;
+      NDX *ndx;
       int k, t;
       if (x->type != 'X')
          fatal("invalid operand of arithmetic aggregate operation");
@@ -725,7 +730,7 @@ SPAR *summation(SPAR *x, int n, int mute[MAX_DIM])
       }
       z->first = z->last = NULL;
       /* perform summation */
-      create_index(z);
+      ndx = create_index(z);
       while (x->first != NULL)
       {  memb = x->first;
          x->first = memb->next;
@@ -735,7 +740,7 @@ SPAR *summation(SPAR *x, int n, int mute[MAX_DIM])
             insist(t >= 0);
             item[k] = memb->item[t];
          }
-         temp = find_memb(item);
+         temp = find_memb(ndx, item);
          if (temp == NULL)
          {  /* member not found */
             for (k = 0; k < z->dim; k++) memb->item[k] = item[k];
@@ -745,7 +750,7 @@ SPAR *summation(SPAR *x, int n, int mute[MAX_DIM])
             else
                z->last->next = memb;
             z->last = memb;
-            index_memb(memb);
+            index_memb(ndx, memb);
          }
          else
          {  /* member already exists */
@@ -753,7 +758,7 @@ SPAR *summation(SPAR *x, int n, int mute[MAX_DIM])
             dmp_free_atom(pdb->memb_pool, memb);
          }
       }
-      delete_index();
+      delete_index(ndx);
       dmp_free_atom(pdb->spar_pool, x);
       return z;
 }
