@@ -26,7 +26,7 @@
 #include <ctype.h>
 #include <stdio.h>
 #include <string.h>
-#include "glplang.h"
+#include "glplan.h"
 #include "glplib.h"
 
 /*----------------------------------------------------------------------
@@ -67,6 +67,7 @@ void assign_stmt(void)
       MEMB *memb, *list;
       ITEM *item[MAX_DIM];
       AVLNODE *node;
+      NDX *ndx;
       int k, t;
       /* determine array in the left part */
       insist(token == T_NAME);
@@ -114,7 +115,8 @@ void assign_stmt(void)
             fatal("too many subscripts for `%s'", spar->name);
          if (token == T_NAME)
          {  /* parse mute letter */
-            if (!(strlen(image) == 1 && islower(image[0])))
+            if (!(strlen(image) == 1 &&
+               islower((unsigned char)image[0])))
                fatal("invalid mute letter `%s'", image);
             /* identical mute letters should refer to identical sets */
             t = find_mute(k, mute, image[0]);
@@ -152,7 +154,7 @@ void assign_stmt(void)
          fatal("too few subscripts for `%s'", spar->name);
       get_token(/* ] */);
 skip: /* parse optional predicate */
-      cond = NULL;
+      cond = NULL, ndx = NULL;
       if (t_name("where"))
       {  get_token(/* where */);
          cond = expression();
@@ -178,9 +180,9 @@ skip: /* parse optional predicate */
                cond = expand_spar(cond, spar->set[k], mute[k]);
          }
          /* index members of the predicate */
-         create_index(cond);
+         ndx = create_index(cond);
          for (memb = cond->first; memb != NULL; memb = memb->next)
-            index_memb(memb);
+            index_memb(ndx, memb);
       }
       /* check left part delimiter */
       if (!t_spec(":=")) fatal("missing delimiter `:='");
@@ -254,7 +256,7 @@ skip: /* parse optional predicate */
                insist(t >= 0);
                item[k] = memb->item[t];
             }
-            if (find_memb(item) == NULL) goto keep;
+            if (find_memb(ndx, item) == NULL) goto keep;
          }
          /* destroy the current member */
          if (spar->type == 'P')
@@ -340,7 +342,7 @@ keep:    /* keep the current member */
                item[k] = memb->item[t];
             }
             /* check the predicate */
-            if (find_memb(item) == NULL)
+            if (find_memb(ndx, item) == NULL)
             {  /* predicate is *false* */
                if (that->type == 'X')
                {  insist(memb->link != NULL);
@@ -359,13 +361,13 @@ keep:    /* keep the current member */
             }
          }
          /* predicate is no longer needed */
-         delete_index();
+         delete_index(ndx);
          erase_spar(cond);
       }
       /* index members of the array in the left part */
-      create_index(spar);
+      ndx = create_index(spar);
       for (memb = spar->first; memb != NULL; memb = memb->next)
-         index_memb(memb);
+         index_memb(ndx, memb);
       /* perform assignment (spar := spar U that) */
       while (that->first != NULL)
       {  MEMB *temp;
@@ -421,7 +423,7 @@ keep:    /* keep the current member */
             goto add;
          }
          /* pseudo arrays */
-         temp = find_memb(memb->item);
+         temp = find_memb(ndx, memb->item);
          if (temp != NULL)
          {  /* check for constant expression */
             expr = memb->link;
@@ -482,7 +484,7 @@ keep:    /* keep the current member */
          continue;
 add:     /* add right part member to the left part array */
          /* there should be NO multiplets */
-         insist(find_memb(memb->item) == NULL);
+         insist(find_memb(ndx, memb->item) == NULL);
          memb->next = NULL;
          if (spar->first == NULL)
             spar->first = memb;
@@ -490,7 +492,7 @@ add:     /* add right part member to the left part array */
             spar->last->next = memb;
          spar->last = memb;
       }
-      delete_index();
+      delete_index(ndx);
       dmp_free_atom(pdb->spar_pool, that);
       /* check delimiter */
       if (!t_spec(";")) fatal("semicolon expected");
