@@ -57,6 +57,7 @@
 
 int lib_init_env(void)
 {     LIBENV *env;
+      int k;
       /* retrieve a pointer to the environmental block */
       env = lib_get_ptr();
       /* check if the environment has been already initialized */
@@ -76,6 +77,7 @@ int lib_init_env(void)
       env->mem_tpeak = 0;
       env->mem_count = 0;
       env->mem_cpeak = 0;
+      for (k = 0; k < LIB_MAX_OPEN; k++) env->file_slot[k] = NULL;
       /* store a pointer to the environmental block */
       lib_set_ptr(env);
       /* initialization completed */
@@ -149,16 +151,20 @@ LIBENV *lib_env_ptr(void)
 
 int lib_free_env(void)
 {     LIBENV *env;
+      int k;
       /* retrieve a pointer to the environmental block */
       env = lib_get_ptr();
       /* check if the environment is active */
       if (env == NULL) return 1;
-      /* free memory block, which are still allocated */
+      /* free memory blocks, which are still allocated */
       while (env->mem_ptr != NULL)
-      {  LIBMEM *this = env->mem_ptr;
-         env->mem_ptr = this->next;
-         free(this);
+      {  LIBMEM *blk = env->mem_ptr;
+         env->mem_ptr = blk->next;
+         free(blk);
       }
+      /* close i/o streams, which are still open */
+      for (k = 0; k < LIB_MAX_OPEN; k++)
+         if (env->file_slot[k] != NULL) fclose(env->file_slot[k]);
       /* free memory allocated to the environmental block */
       free(env);
       /* reset a pointer to the environmental block */
@@ -366,7 +372,7 @@ void *umalloc(int size)
       memset(desc, '?', size);
 #endif
       desc->size = size;
-      desc->flag = LIBMEM_FLAG;
+      desc->flag = LIB_MEM_FLAG;
       desc->prev = NULL;
       desc->next = env->mem_ptr;
       if (desc->next != NULL) desc->next->prev = desc;
@@ -432,7 +438,7 @@ void ufree(void *ptr)
       if (ptr == NULL)
          fault("ufree: ptr = %p; null pointer", ptr);
       desc = (void *)((char *)ptr - size_of_desc);
-      if (desc->flag != LIBMEM_FLAG)
+      if (desc->flag != LIB_MEM_FLAG)
          fault("ufree: ptr = %p; invalid pointer", ptr);
       if (env->mem_total < desc->size || env->mem_count == 0)
          fault("ufree: ptr = %p; memory allocation error", ptr);
@@ -451,6 +457,68 @@ void ufree(void *ptr)
       return;
 }
 
+/*----------------------------------------------------------------------
+-- ufopen - open file.
+--
+-- *Synopsis*
+--
+-- #include "glplib.h"
+-- void *ufopen(char *fname, char *mode);
+--
+-- *Description*
+--
+-- The routine ufopen opens a file using the character string fname as
+-- the file name and the character string mode as the open mode.
+--
+-- *Returns*
+--
+-- If the file has been open successfully, the routine ufopen returns a
+-- pointer to an i/o stream associated with the file (i.e. a pointer to
+-- an object of FILE type). Otherwise the routine return NULL. */
+
+void *ufopen(char *fname, char *mode)
+{     LIBENV *env = lib_env_ptr();
+      int k;
+      /* find free slot */
+      for (k = 0; k < LIB_MAX_OPEN; k++)
+         if (env->file_slot[k] == NULL) break;
+      if (k == LIB_MAX_OPEN)
+         fault("ufopen: too many open files");
+      /* open a file and store a pointer to the i/o stream */
+      env->file_slot[k] = fopen(fname, mode);
+      return env->file_slot[k];
+}
+
+/*----------------------------------------------------------------------
+-- ufclose - close file.
+--
+-- *Synopsis*
+--
+-- #include "glplib.h"
+-- void ufclose(void *fp);
+--
+-- *Description*
+--
+-- The routine ufclose closes a file associated with i/o stream, which
+-- the parameter fp points to. It is assumed that the file was open by
+-- the routine ufopen. */
+
+void ufclose(void *fp)
+{     LIBENV *env = lib_env_ptr();
+      int k;
+      /* check if the i/o stream pointer is valid */
+      if (fp == NULL)
+         fault("ufclose: fp = %p; null i/o stream", fp);
+      for (k = 0; k < LIB_MAX_OPEN; k++)
+         if (env->file_slot[k] == fp) break;
+      if (k == LIB_MAX_OPEN)
+         fault("ufclose: fp = %p; invalid i/o stream", fp);
+      /* close a file and free the corresponding slot */
+      fclose(fp);
+      env->file_slot[k] = NULL;
+      return;
+}
+
 /*----------------------------------------------------------------------
 -- jday - convert calendar date to Julian day.
 --
