@@ -337,7 +337,7 @@ void lpx_add_cols(LPX *lp, int ncs)
 int lpx_check_name(char *name)
 {     int t;
       for (t = 0; name[t] != '\0'; t++)
-         if (t == 255 || !isgraph(name[t])) return 1;
+         if (t == 255 || !isgraph((unsigned char)name[t])) return 1;
       return 0;
 }
 
