@@ -1320,6 +1320,19 @@ done: /* deallocate the common block */
 int lpx_simplex(LPX *lp)
 {     int ret;
 #     define prefix "lpx_simplex: "
+      /* check that each double-bounded variable has correct lower and
+         upper bounds */
+      {  int k;
+         for (k = 1; k <= lp->m + lp->n; k++)
+         {  if (lp->typx[k] == LPX_DB && lp->lb[k] > lp->ub[k])
+            {  if (lp->msg_lev >= 1)
+                  print(prefix "double-bounded variable %d has invalid "
+                     "bounds", k);
+               ret = LPX_E_FAULT;
+               goto done;
+            }
+         }
+      }
       /* "warm up" the initial basis */
       ret = lpx_warm_up(lp);
       switch (ret)
