@@ -1379,4 +1379,222 @@ int lpx_mixed_gomory(LPX *lp, int kind[], int len, int ndx[],
       return len;
 }
 
+/*----------------------------------------------------------------------
+-- lpx_estim_obj_chg - estimate obj. changes for down- and up-branch.
+--
+-- *Synopsis*
+--
+-- #include "glplpx.h"
+-- void lpx_estim_obj_chg(LPX *lp, int k, double dn_val, double up_val,
+--    double *dn_chg, double *up_chg, int ndx[], double val[]);
+--
+-- *Description*
+--
+-- The routine lpx_estim_chg computes estimations of the changes in the
+-- objective function for the down-branch and the up-branch by means of
+-- one implicit iteration of the dual simplex for each branch.
+--
+-- The current basic solution of an LP problem, which the parameter lp
+-- points to, should be optimal.
+--
+-- The parameter k is the number of some variable x[k], for which the
+-- routine has to compute the estimations. If 1 <= k <= m, the variable
+-- x[k] is auxiliary, if m+1 <= k <= m+n, it is structural (where m and
+-- n are numbers of rows and columns, respectively). The variable x[k]
+-- should be basic in the current basic solution.
+--
+-- The parameter dn_val is a new *upper* bound of the variable x[k] in
+-- the down-branch, and the parameter up_val is a new *lower* bound of
+-- the variable x[k] in the up-branch. These new bounds should satisfy
+-- to dn_val <= beta[k] <= up_val, where beta[k] is a value of x[k] in
+-- the current basic solution.
+--
+-- The down-branch is equivalent to the original LP problem provided
+-- with the additional constraint x[k] <= dn_val. And, analogously, the
+-- up-branch is equivalent to the original LP problem provided with the
+-- additional constraint x[k] >= up_val. These additional constraints
+-- are included implicitly, so the original LP problem is not changed.
+--
+-- Estimation of the change in the objective function is computed as
+-- the difference between a value, which the objective function would
+-- have in an adjacent basis as the result of one iteration of the dual
+-- simplex, and the value, which it has in the current basic solution.
+-- The current basic solution is optimal and the adjacent basis is dual
+-- feasible, so the actual change on solving the branch to optimality
+-- is always not less (in the case of minimization) or not greater (in
+-- the case of maximization) than its estimation.
+--
+-- If some branch has no primal feasible solution, its esimation is set
+-- to +DBL_MAX (for minimization) or to -DBL_MAX (for maximization).
+--
+-- The routine stores computed estimations for the down-branch and the
+-- up-branch to locations, which the parameters dn_chg and up_chg point
+-- to, respectively.
+--
+-- The working arrays ndx and val should have at least 1+n locations,
+-- where n is number of columns in the problem. If some of these arrays
+-- is specified as NULL, it is allocated and freed by the routine.
+--
+-- *Algorithm*
+--
+-- Let x[k] be the specified variable, which leaves the current basis
+-- and decreasing goes to its new upper bound (for the down-branch) or
+-- increasing goes to its new lower bound (for the up-branch). Let also
+-- x[s] be a non-basic (auxiliary or structural) variable chosen by the
+-- dual ratio test to enter the basis in order to keep dual feasibility
+-- of the adjacent basis. The dependence between x[k] and x[s] is given
+-- by the corresponding row of the simplex table:
+--
+--    x[k] = ... + alfa * x[s] + ...                                 (1)
+--
+-- where alfa is an influence coefficient.
+--
+-- Let
+--
+--                                     dn_val - beta[k] (dn-branch)
+--    delta[k] = beta'[k] - beta[k] =                                (2)
+--                                     up_val - beta[k] (up-branch)
+--
+-- be the change of x[k], and
+--
+--    delta[s] = beta'[s] - beta[s]                                  (3)
+--
+-- be the change of x[s], where beta is a value of the corresponding
+-- variable in the current (optimal) basis, and beta' is a value in the
+-- adjacent (dual feasible) basis.
+--
+-- From (1) it follows that
+--
+--    delta[k] = alfa * delta[s],                                    (4)
+--
+-- or
+--
+--    delta[s] = delta[k] / alfa.                                    (5)
+--
+-- Thus, using the reduced cost d[s] of the non-basic variable x[s] in
+-- the current basis it is possible to find the corresponding change in
+-- the objective function:
+--
+--    delta[Z] = Z' - Z = d[s] * delta[s],                           (6)
+--
+-- which is the estimation of the actual change if the branch would be
+-- solved to optimality. May note that Z' (an objective value in the
+-- adjacent basis) is always *not better* than Z (an objective value in
+-- the current basis). */
+
+void lpx_estim_obj_chg(LPX *lp, int k, double dn_val, double up_val,
+      double *dn_chg, double *up_chg, int _ndx[], double _val[])
+{     int m, n, dir, s, t, len, tagx, *ndx = _ndx;
+      double alfa, vx, dx, tol, eps, *val = _val;
+      /* the current basic solution should be optimal */
+      if (lpx_get_status(lp) != LPX_OPT)
+         fault("lpx_estim_obj_chg: basic solution is not optimal");
+      /* determine number of rows and columns */
+      m = lpx_get_num_rows(lp);
+      n = lpx_get_num_cols(lp);
+      /* check if the number k is correct */
+      if (!(1 <= k && k <= m+n))
+         fault("lpx_estim_obj_chg: k = %d; number of variable out of ra"
+            "nge", k);
+      /* obtain the status and value of the variable x[k] */
+      if (k <= m)
+         lpx_get_row_info(lp, k, &tagx, &vx, NULL);
+      else
+         lpx_get_col_info(lp, k-m, &tagx, &vx, NULL);
+      /* the variable x[k] should be basic */
+      if (tagx != LPX_BS)
+         fault("lpx_estim_obj_chg: k = %d; variable is not basic", k);
+      /* check correctness of new bounds of the variable x[k] */
+      if (!(dn_val <= vx))
+         fault("lpx_estim_obj_chg: dn_val = %g; vx = %g; invalid bound "
+            "for down-branch", dn_val, vx);
+      if (!(up_val >= vx))
+         fault("lpx_estim_obj_chg: up_val = %g; vx = %g; invalid bound "
+            "for up-branch", up_val, vx);
+      /* allocate working arrays */
+      if (_ndx == NULL) ndx = ucalloc(1+n, sizeof(int));
+      if (_val == NULL) val = ucalloc(1+n, sizeof(double));
+      /* determine optimization direction */
+      dir = lpx_get_obj_dir(lp);
+      /* obtain a relative tolerance used to check pivots */
+      tol = lpx_get_real_parm(lp, LPX_K_TOLPIV);
+      /* compute the row of the simplex table, which correspond to the
+         variable x[k] */
+      len = lpx_eval_tab_row(lp, k, ndx, val);
+      /*** estimate obj. change for the down-branch ***/
+      /* perform dual ratio test to determine which non-basic variable
+         should enter the basis if the variable x[k] decreasing leaves
+         the basis and goes to its new upper bound */
+      s = lpx_dual_ratio_test(lp, len, ndx, val, -1, tol);
+      if (s == 0)
+      {  /* the down-branch has no primal feasible solution */
+         *dn_chg = (dir == LPX_MIN ? +DBL_MAX : -DBL_MAX);
+      }
+      else
+      {  /* determine the corresponding influence coefficient */
+         for (t = 1; t <= len; t++) if (ndx[t] == s) break;
+         insist(t <= len);
+         alfa = val[t];
+         /* obtain the current reduced cost of the variable x[s] */
+         if (s <= m)
+            lpx_get_row_info(lp, s, NULL, NULL, &dx);
+         else
+            lpx_get_col_info(lp, s-m, NULL, NULL, &dx);
+         /* compute the change of the objective function */
+         *dn_chg = dx * ((dn_val - vx) / alfa);
+      }
+      /*** estimate obj. change for the up-branch ***/
+      /* perform dual ratio test to determine which non-basic variable
+         should enter the basis if the variable x[k] increasing leaves
+         the basis and goes to its new lower bound */
+      s = lpx_dual_ratio_test(lp, len, ndx, val, +1, tol);
+      if (s == 0)
+      {  /* the up-branch has no primal feasible solution */
+         *up_chg = (dir == LPX_MIN ? +DBL_MAX : -DBL_MAX);
+      }
+      else
+      {  /* determine the corresponding influence coefficient */
+         for (t = 1; t <= len; t++) if (ndx[t] == s) break;
+         insist(t <= len);
+         alfa = val[t];
+         /* obtain the current reduced cost of the variable x[s] */
+         if (s <= m)
+            lpx_get_row_info(lp, s, NULL, NULL, &dx);
+         else
+            lpx_get_col_info(lp, s-m, NULL, NULL, &dx);
+         /* compute the change of the objective function */
+         *up_chg = dx * ((up_val - vx) / alfa);
+      }
+      /* if the adjacent basic solution of the down- or up-branch is
+         dual degenerative, the estimations may have wrong sign (due to
+         wrong sign of the reduced cost of x[s], which in this case has
+         to be close to zero) */
+      eps = 1e-6 * (1.0 + fabs(lpx_get_obj_val(lp)));
+      switch (dir)
+      {  case LPX_MIN:
+            /* in the case of minimization both estimations should be
+               non-negative */
+            insist(*dn_chg >= -eps);
+            insist(*up_chg >= -eps);
+            if (*dn_chg < 0.0) *dn_chg = 0.0;
+            if (*up_chg < 0.0) *up_chg = 0.0;
+            break;
+         case LPX_MAX:
+            /* in the case of maximization both estimations should be
+               non-positive */
+            insist(*dn_chg <= +eps);
+            insist(*up_chg <= +eps);
+            if (*dn_chg > 0.0) *dn_chg = 0.0;
+            if (*up_chg > 0.0) *up_chg = 0.0;
+            break;
+         default:
+            insist(dir != dir);
+      }
+      /* free working arrays */
+      if (_ndx == NULL) ufree(ndx);
+      if (_val == NULL) ufree(val);
+      /* return to the calling program */
+      return;
+}
+
 /* eof */
