@@ -335,7 +335,14 @@ static char *mps_numb(double val, char numb[12+1])
       char str[255+1], *e;
       for (n = 12; n >= 6; n--)
       {  if (val != 0.0 && fabs(val) < 0.002)
+#if 0
             sprintf(str, "%.*E", n, val);
+#else
+            /* n is number of desired decimal places, but in case of E
+               format precision means number of digits that follow the
+               decimal point */
+            sprintf(str, "%.*E", n - 1, val);
+#endif
          else
             sprintf(str, "%.*G", n, val);
          insist(strlen(str) <= 255);
@@ -345,7 +352,7 @@ static char *mps_numb(double val, char numb[12+1])
       }
       fault("lpx_write_mps: can't convert floating point number '%g' to"
          " character string", val);
-      return NULL; /* to relax the compiler */
+      return NULL; /* make the compiler happy */
 }
 
 int lpx_write_mps(LPX *lp, char *fname)
