@@ -30,6 +30,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "glpavl.h"
+#include "glplib.h"
 #include "glpmps.h"
 #include "glpstr.h"
 
@@ -120,12 +121,12 @@ MPS *load_mps(char *_fname)
       seqn = 0;
       mps = umalloc(sizeof(MPS));
       memset(mps, 0, sizeof(MPS));
-      mps->pool = create_pool(0);
-      t_row = create_avl((int (*)(void *, void *))strcmp);
-      t_col = create_avl((int (*)(void *, void *))strcmp);
-      t_rhs = create_avl((int (*)(void *, void *))strcmp);
-      t_rng = create_avl((int (*)(void *, void *))strcmp);
-      t_bnd = create_avl((int (*)(void *, void *))strcmp);
+      mps->pool = dmp_create_pool(0);
+      t_row = avl_create_tree(NULL, avl_strcmp);
+      t_col = avl_create_tree(NULL, avl_strcmp);
+      t_rhs = avl_create_tree(NULL, avl_strcmp);
+      t_rng = avl_create_tree(NULL, avl_strcmp);
+      t_bnd = avl_create_tree(NULL, avl_strcmp);
       /* process NAME indicator card */
       if (read_card()) goto fail;
       if (memcmp(card, "NAME ", 5) != 0)
@@ -134,7 +135,7 @@ MPS *load_mps(char *_fname)
       }
       memcpy(f3, card+14, 8); f3[8] = '\0'; strspx(f3);
       if (f3[0] == '\0') strcpy(f3, unknown);
-      mps->name = get_atomv(mps->pool, strlen(f3)+1);
+      mps->name = dmp_get_atomv(mps->pool, strlen(f3)+1);
       strcpy(mps->name, f3);
       print("load_mps: name `%s'", mps->name);
       /* process ROWS section */
@@ -156,8 +157,8 @@ MPS *load_mps(char *_fname)
       print("load_mps: %d columns", mps->n_col);
       /* count non-zeros */
       {  int nz = 0;
-         for (node = next_node(t_col, NULL); node != NULL;
-            node = next_node(t_col, node))
+         for (node = avl_find_next_node(t_col, NULL); node != NULL;
+            node = avl_find_next_node(t_col, node))
          {  col = node->link;
             for (cqe = col->ptr; cqe != NULL; cqe = cqe->next) nz++;
          }
@@ -195,14 +196,14 @@ MPS *load_mps(char *_fname)
       fclose(fp);
       /* build row list */
       mps->row = ucalloc(1+mps->n_row, sizeof(MPSROW *));
-      for (node = next_node(t_row, NULL); node != NULL;
-         node = next_node(t_row, node))
+      for (node = avl_find_next_node(t_row, NULL); node != NULL;
+         node = avl_find_next_node(t_row, node))
          mps->row[node->type] = node->link;
-      delete_avl(t_row);
+      avl_delete_tree(t_row);
       /* build column list and restore original order of elements */
       mps->col = ucalloc(1+mps->n_col, sizeof(MPSCOL *));
-      for (node = next_node(t_col, NULL); node != NULL;
-         node = next_node(t_col, node))
+      for (node = avl_find_next_node(t_col, NULL); node != NULL;
+         node = avl_find_next_node(t_col, node))
       {  col = node->link; cptr = NULL;
          while (col->ptr != NULL)
          {  cqe = col->ptr;
@@ -213,11 +214,11 @@ MPS *load_mps(char *_fname)
          col->ptr = cptr;
          mps->col[node->type] = col;
       }
-      delete_avl(t_col);
+      avl_delete_tree(t_col);
       /* build rhs list and restore original order of elements */
       mps->rhs = ucalloc(1+mps->n_rhs, sizeof(MPSCOL *));
-      for (node = next_node(t_rhs, NULL); node != NULL;
-         node = next_node(t_rhs, node))
+      for (node = avl_find_next_node(t_rhs, NULL); node != NULL;
+         node = avl_find_next_node(t_rhs, node))
       {  col = node->link; cptr = NULL;
          while (col->ptr != NULL)
          {  cqe = col->ptr;
@@ -228,11 +229,11 @@ MPS *load_mps(char *_fname)
          col->ptr = cptr;
          mps->rhs[node->type] = col;
       }
-      delete_avl(t_rhs);
+      avl_delete_tree(t_rhs);
       /* build ranges list and restore original order of elements */
       mps->rng = ucalloc(1+mps->n_rng, sizeof(MPSCOL *));
-      for (node = next_node(t_rng, NULL); node != NULL;
-         node = next_node(t_rng, node))
+      for (node = avl_find_next_node(t_rng, NULL); node != NULL;
+         node = avl_find_next_node(t_rng, node))
       {  col = node->link; cptr = NULL;
          while (col->ptr != NULL)
          {  cqe = col->ptr;
@@ -243,11 +244,11 @@ MPS *load_mps(char *_fname)
          col->ptr = cptr;
          mps->rng[node->type] = col;
       }
-      delete_avl(t_rng);
+      avl_delete_tree(t_rng);
       /* build bounds list and restore original order of elements */
       mps->bnd = ucalloc(1+mps->n_bnd, sizeof(MPSBND *));
-      for (node = next_node(t_bnd, NULL); node != NULL;
-         node = next_node(t_bnd, node))
+      for (node = avl_find_next_node(t_bnd, NULL); node != NULL;
+         node = avl_find_next_node(t_bnd, node))
       {  bnd = node->link; bptr = NULL;
          while (bnd->ptr != NULL)
          {  bqe = bnd->ptr;
@@ -258,7 +259,7 @@ MPS *load_mps(char *_fname)
          bnd->ptr = bptr;
          mps->bnd[node->type] = bnd;
       }
-      delete_avl(t_bnd);
+      avl_delete_tree(t_bnd);
       /* restore original order of quadratic form elements */
       qptr = NULL;
       while (mps->quad != NULL)
@@ -272,7 +273,7 @@ MPS *load_mps(char *_fname)
       return mps;
 fail: /* something wrong in Danish kingdom */
       if (mps != NULL)
-      {  if (mps->pool != NULL) delete_pool(mps->pool);
+      {  if (mps->pool != NULL) dmp_delete_pool(mps->pool);
          if (mps->row != NULL) ufree(mps->row);
          if (mps->col != NULL) ufree(mps->col);
          if (mps->rhs != NULL) ufree(mps->rhs);
@@ -280,11 +281,11 @@ fail: /* something wrong in Danish kingdom */
          if (mps->bnd != NULL) ufree(mps->bnd);
          ufree(mps);
       }
-      if (t_row != NULL) delete_avl(t_row);
-      if (t_col != NULL) delete_avl(t_col);
-      if (t_rhs != NULL) delete_avl(t_rhs);
-      if (t_rng != NULL) delete_avl(t_rng);
-      if (t_bnd != NULL) delete_avl(t_bnd);
+      if (t_row != NULL) avl_delete_tree(t_row);
+      if (t_col != NULL) avl_delete_tree(t_col);
+      if (t_rhs != NULL) avl_delete_tree(t_rhs);
+      if (t_rng != NULL) avl_delete_tree(t_rng);
+      if (t_bnd != NULL) avl_delete_tree(t_bnd);
       if (fp != NULL) fclose(fp);
       return NULL;
 }
@@ -421,16 +422,16 @@ loop: /* process the next data card */
          return 1;
       }
       /* create new row */
-      if (find_by_key(t_row, f2))
+      if (avl_find_by_key(t_row, f2) != NULL)
       {  print("%s:%d: row `%s' multiply specified", fname, seqn, f2);
          return 1;
       }
-      row = get_atomv(mps->pool, sizeof(MPSROW));
-      row->name = get_atomv(mps->pool, strlen(f2)+1);
+      row = dmp_get_atomv(mps->pool, sizeof(MPSROW));
+      row->name = dmp_get_atomv(mps->pool, strlen(f2)+1);
       strcpy(row->name, f2);
       strcpy(row->type, f1);
       /* add row name to the symbol table */
-      node = insert_by_key(t_row, row->name);
+      node = avl_insert_by_key(t_row, row->name);
       node->type = t_row->size;
       node->link = row;
       goto loop;
@@ -494,16 +495,16 @@ loop: /* process the next data card */
       }
       strcpy(name, f2);
       /* search for column or vector specified in field 2 */
-      node = find_by_key(t_xxx, f2);
+      node = avl_find_by_key(t_xxx, f2);
       if (node == NULL)
       {  /* not found; create new column or vector */
-         col = get_atomv(mps->pool, sizeof(MPSCOL));
-         col->name = get_atomv(mps->pool, strlen(f2)+1);
+         col = dmp_get_atomv(mps->pool, sizeof(MPSCOL));
+         col->name = dmp_get_atomv(mps->pool, strlen(f2)+1);
          strcpy(col->name, f2);
          col->flag = 0;
          col->ptr = NULL;
          /* add column or vector name to the symbol table */
-         node = insert_by_key(t_xxx, col->name);
+         node = avl_insert_by_key(t_xxx, col->name);
          node->type = t_xxx->size;
          node->link = col;
       }
@@ -530,7 +531,7 @@ loop: /* process the next data card */
          return 1;
       }
       /* create new column or vector element */
-      ref = find_by_key(t_row, f3);
+      ref = avl_find_by_key(t_row, f3);
       if (ref == NULL)
       {  print("%s:%d: row `%s' not found", fname, seqn, f3);
          return 1;
@@ -539,7 +540,7 @@ loop: /* process the next data card */
       {  print("%s:%d: invalid value `%s'", fname, seqn, f4);
          return 1;
       }
-      cqe = get_atomv(mps->pool, sizeof(MPSCQE));
+      cqe = dmp_get_atomv(mps->pool, sizeof(MPSCQE));
       cqe->ind = ref->type;
       cqe->val = val;
       cqe->next = col->ptr;
@@ -555,7 +556,7 @@ loop: /* process the next data card */
          return 1;
       }
       /* create new column or vector element */
-      ref = find_by_key(t_row, f5);
+      ref = avl_find_by_key(t_row, f5);
       if (ref == NULL)
       {  print("%s:%d: row `%s' not found", fname, seqn, f5);
          return 1;
@@ -564,7 +565,7 @@ loop: /* process the next data card */
       {  print("%s:%d: invalid value `%s'", fname, seqn, f6);
          return 1;
       }
-      cqe = get_atomv(mps->pool, sizeof(MPSCQE));
+      cqe = dmp_get_atomv(mps->pool, sizeof(MPSCQE));
       cqe->ind = ref->type;
       cqe->val = val;
       cqe->next = col->ptr;
@@ -623,15 +624,15 @@ loop: /* process the next data card */
          return 1;
       }
       /* search for bound vector specified in field 2 */
-      node = find_by_key(t_bnd, f2);
+      node = avl_find_by_key(t_bnd, f2);
       if (node == NULL)
       {  /* not found; create new bound vector */
-         bnd = get_atomv(mps->pool, sizeof(MPSBND));
-         bnd->name = get_atomv(mps->pool, strlen(f2)+1);
+         bnd = dmp_get_atomv(mps->pool, sizeof(MPSBND));
+         bnd->name = dmp_get_atomv(mps->pool, strlen(f2)+1);
          strcpy(bnd->name, f2);
          bnd->ptr = NULL;
          /* add vector name to the symbol table */
-         node = insert_by_key(t_bnd, bnd->name);
+         node = avl_insert_by_key(t_bnd, bnd->name);
          node->type = t_bnd->size;
          node->link = bnd;
       }
@@ -646,7 +647,7 @@ loop: /* process the next data card */
       }
 #endif
       /* process column-element pair */
-      ref = find_by_key(t_col, f3);
+      ref = avl_find_by_key(t_col, f3);
       if (ref == NULL)
       {  print("%s:%d: column `%s' not found", fname, seqn, f3);
          return 1;
@@ -657,7 +658,7 @@ loop: /* process the next data card */
          return 1;
       }
       /* create new bound vector element */
-      bqe = get_atomv(mps->pool, sizeof(MPSBQE));
+      bqe = dmp_get_atomv(mps->pool, sizeof(MPSBQE));
       strcpy(bqe->type, f1);
       bqe->ind = ref->type;
       bqe->val = val;
@@ -713,12 +714,12 @@ loop: /* process the next data card */
       {  print("%s:%d: missing value in field 4", fname, seqn);
          return 1;
       }
-      ref1 = find_by_key(t_col, f2);
+      ref1 = avl_find_by_key(t_col, f2);
       if (ref1 == NULL)
       {  print("%s:%d: column `%s' not found", fname, seqn, f2);
          return 1;
       }
-      ref2 = find_by_key(t_col, f3);
+      ref2 = avl_find_by_key(t_col, f3);
       if (ref2 == NULL)
       {  print("%s:%d: column `%s' not found", fname, seqn, f3);
          return 1;
@@ -729,7 +730,7 @@ loop: /* process the next data card */
          return 1;
       }
       /* create new quadratic form element */
-      qfe = get_atomv(mps->pool, sizeof(MPSQFE));
+      qfe = dmp_get_atomv(mps->pool, sizeof(MPSQFE));
       qfe->ind1 = ref1->type;
       qfe->ind2 = ref2->type;
       qfe->val = val;
@@ -753,7 +754,7 @@ done: return 0;
 -- type that represents linear programming model in the MPS format. */
 
 void free_mps(MPS *mps)
-{       delete_pool(mps->pool);
+{       dmp_delete_pool(mps->pool);
         ufree(mps->row);
         ufree(mps->col);
         ufree(mps->rhs);
