@@ -728,10 +728,12 @@ int spx_prim_chuzr(SPX *spx, double relax)
          if (temp < 0.0) temp = - temp;
          if (big < temp) big = temp;
       }
+#if 0
       /* if all elements of the q-th column of the simplex table are
          too small, tell the calling program to reinvert the basis and
          repeat the choice */
       if (big < lp->tol_piv) ret = 1;
+#endif
       /* compute the absolute tolerance eps used to check elements of
          the q-th column */
       eps = lp->tol_piv * (1.0 + big);
@@ -1006,10 +1008,12 @@ int spx_dual_chuzc(SPX *spx, double relax)
          if (temp < 0.0) temp = - temp;
          if (big < temp) big = temp;
       }
+#if 0
       /* if all elements in the p-th row of the simplex table are too
          small, tell the calling program to reinvert the basis and then
          repeat the choice */
       if (big < lp->tol_piv) ret = 1;
+#endif
       /* compute the absolute tolerance eps used to check elements of
          the p-th row */
       eps = lp->tol_piv * (1.0 + big);
